@@ -16,8 +16,6 @@
 import logging
 import logging.config
 
-from  lava_test.core.config import get_config
-
 from lava_tool.dispatcher import LavaDispatcher, run_with_dispatcher_class
 
 
@@ -34,25 +32,14 @@ class LAVATestDispatcher(LavaDispatcher):
 
 
 def main():
-
-    logging_config_file = get_config().get_logging_config_file()
-
-    if logging_config_file != None:
-        logging.config.fileConfig(logging_config_file)
-    else:
-        # config the python logging
-       FORMAT = '<LAVA_TEST>%(asctime)s %(levelname)s: %(message)s'
-       DATEFMT= '%Y-%m-%d %I:%M:%S %p'
-       logging.basicConfig(format=FORMAT,datefmt=DATEFMT)
-       logging.root.setLevel(logging.ERROR)
-
-    run_with_dispatcher_class(LAVATestDispatcher)
+    # default logging level is warning. -v or --verbose will change it to debug
+    # (in Command class).
+    FORMAT = '<LAVA_TEST>%(asctime)s %(levelname)s: %(message)s'
+    DATEFMT = '%Y-%m-%d %I:%M:%S %p'
+    logging.basicConfig(format=FORMAT, datefmt=DATEFMT)
+    logging.root.setLevel(logging.WARNING)
+    return run_with_dispatcher_class(LAVATestDispatcher)
 
 
 if __name__ == '__main__':
-    import os
-    import sys
-    arg_only = sys.argv
-    arg_only.remove(arg_only[0])
-    code = LAVATestDispatcher().dispatch(arg_only)
-    if (code != 0): exit(code)
\ No newline at end of file
+    raise SystemExit(main())
