@@ -1,4 +1,4 @@
-# Copyright (c) 2010, 2011 Linaro
+#, Copyright (c) 2010, 2011 Linaro
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,8 +14,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-The Linux Test Project is a collection of tools for testing Linux with a 
-focus on the kernel.
+The Linux Test Project is a collection of tools for testing Linux with a focus
+on the kernel.
 
 **URL:** http://ltp.sourceforge.net
 
@@ -31,9 +31,10 @@ from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
 
-VERSION="20100831"
-URL='http://downloads.sourceforge.net/project/ltp/LTP Source/ltp-%s/ltp-full-%s.bz2' % (VERSION, VERSION)
-MD5="6982c72429a62f3917c13b2d529ad1ce"
+VERSION = "20100831"
+URL = ('http://downloads.sourceforge.net/project/ltp/'
+       'LTP Source/ltp-%s/ltp-full-%s.bz2') % (VERSION, VERSION)
+MD5 = "6982c72429a62f3917c13b2d529ad1ce"
 DEPS = ['bzip2', 'flex', 'bison', 'make', 'build-essential']
 
 SCRIPT = """
@@ -50,19 +51,24 @@ INSTALLSTEPS = ["echo '%s' > installltp.sh" % SCRIPT,
                 'chmod +x installltp.sh',
                 './installltp.sh']
 RUNSTEPS = ['cd build && sudo ./runltp $(OPTIONS)']
-PATTERN = "^(?P<test_case_id>\S+)    (?P<subid>\d+)  (?P<result>\w+)  :  (?P<message>.+)"
-FIXUPS = {"TBROK":"fail",
-          "TCONF":"skip",
-          "TFAIL":"fail",
-          "TINFO":"unknown",
-          "TPASS":"pass",
-          "TWARN":"unknown"}
+PATTERN = (
+    "^(?P<test_case_id>\S+)"
+    "    (?P<subid>\d+)"
+    "  (?P<result>\w+)"
+    "  :  (?P<message>.+)")
+FIXUPS = {
+    "TBROK": "fail",
+    "TCONF": "skip",
+    "TFAIL": "fail",
+    "TINFO": "unknown",
+    "TPASS": "pass",
+    "TWARN": "unknown"}
 
 
 class LTPParser(TestParser):
+
     def parse(self, artifacts):
         filename = artifacts.stdout_pathname
-        print "filename=%s" %filename
         pat = re.compile(self.pattern)
         with open(filename, 'r') as fd:
             for line in fd.readlines():
@@ -79,10 +85,13 @@ class LTPParser(TestParser):
                         self.analyze_test_result(results))
 
 
-ltpinst = TestInstaller(INSTALLSTEPS, deps=DEPS, url=URL,
-                                           md5=MD5)
-ltprun = TestRunner(RUNSTEPS,default_options = DEFAULT_OPTIONS)
-ltpparser = LTPParser(PATTERN, fixupdict = FIXUPS)
-testobj = Test(test_id="ltp", test_version=VERSION,
-                                  installer=ltpinst, runner=ltprun,
-                                  parser=ltpparser)
+installer = TestInstaller(INSTALLSTEPS, deps=DEPS, url=URL, md5=MD5)
+runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
+parser = LTPParser(PATTERN, fixupdict=FIXUPS)
+
+testobj = Test(
+    test_id="ltp",
+    test_version=VERSION,
+    installer=installer,
+    runner=runner,
+    parser=parser)
