@@ -13,6 +13,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""
+A simple test for the perf performance counters subsystem in Linux.  This 
+currently just runs 'perf test' sanity tests built into the perf tool
+
+**URL:** None
+
+**Default options:** None
+"""
+
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
@@ -20,12 +29,22 @@ from lava_test.core.tests import Test
 
 DEFAULT_OPTIONS = ""
 DEPS = ["linux-tools"]
-RUNSTEPS = ["export PERFBIN=`find /usr/bin/ -name perf_* | sort -r | head -n 1 | xargs basename`; $PERFBIN test 2>&1  $(OPTIONS)"]
+
+RUNSTEPS = [
+    ("export PERFBIN=`find /usr/bin/ -name perf_*"
+     " | sort -r"
+     " | head -n 1"
+     " | xargs basename`;"
+     " $PERFBIN test 2>&1 $(OPTIONS)")]
+
 PATTERN = "^ \d+:\s+(?P<test_case_id>[\w\s]+):\W+(?P<message>\w+)"
 
-perfinst = TestInstaller(deps=DEPS)
-perfrun = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
-perfparser = TestParser(PATTERN,
-                   appendall={"result":"pass"})
-testobj = Test(test_id="perf", installer=perfinst,
-                                  runner=perfrun, parser=perfparser)
+installer = TestInstaller(deps=DEPS)
+runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
+parser = TestParser(PATTERN, appendall={"result": "pass"})
+
+testobj = Test(
+    test_id="perf",
+    installer=installer,
+    runner=runner,
+    parser=parser)
