@@ -14,6 +14,15 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+"""
+X11perf is an xlib based benchmark to see how fast an X server can execute various tests
+
+**URL:** http://cgit.freedesktop.org/xorg/app/x11perf/
+
+**Default options:** -repeat 3 -aa10text -aa24text -aatrapezoid300 -aatrap2x300 -copypixwin500 -copypixpix500 -comppixwin500 -shmput500 -shmputxy500 -scroll500
+"""
+
+
 
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
@@ -44,17 +53,18 @@ x11perf_tests = [
     "-shmputxy500",
 
     "-scroll500",
-    ]
+]
 
 DEFAULT_OPTIONS = "%s %s" % (x11perf_options,  " ".join(x11perf_tests))
 RUNSTEPS = ["x11perf $(OPTIONS)"]
 PATTERN = "trep @.*\(\W*(?P<measurement>\d+.\d+)/sec\):\W+(?P<test_case_id>.+)"
 
-inst = TestInstaller(deps=["x11-apps"])
-run = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
-parse = TestParser(PATTERN,
-                                      appendall={'units':'reps/s',
-                                                 'result':'pass'})
+installer = TestInstaller(deps=["x11-apps"])
+runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
+parser = TestParser(PATTERN, appendall={'units': 'reps/s', 'result': 'pass'})
 
-testobj = Test(test_id="x11perf", installer=inst,
-                                  runner=run, parser=parse)
+testobj = Test(
+    test_id="x11perf",
+    installer=installer,
+    runner=runner,
+    parser=parser)
